resource "aws_s3_bucket" "documentation" {
  bucket = "${local.resource_prefix}-documentation"

  tags = {
    Name = local.resource_prefix
  }
}

resource "aws_s3_bucket_public_access_block" "documentation" {
  bucket = aws_s3_bucket.documentation.id

  block_public_acls       = false
  block_public_policy     = false
  ignore_public_acls      = false
  restrict_public_buckets = false
}

resource "aws_s3_bucket_ownership_controls" "documentation" {
  bucket = aws_s3_bucket.documentation.id
  rule {
    object_ownership = "BucketOwnerPreferred"
  }
  depends_on = [aws_s3_bucket_public_access_block.documentation]
}

# resource "aws_s3_bucket_acl" "s3_demo_bucket" {
#   bucket = aws_s3_bucket.documentation.id

#   acl = "public-read"
# }

resource "aws_s3_bucket_website_configuration" "documentation" {
  bucket = aws_s3_bucket.documentation.id

  index_document {
    suffix = "index.html"
  }
}

resource "aws_s3_bucket_policy" "documentation" {
  bucket = aws_s3_bucket.documentation.id

  policy     = <<POLICY
{
  "Version": "2012-10-17",
  "Statement": [
    {
	  "Sid": "PublicReadGetObject",
      "Effect": "Allow",
      "Principal": "*",
      "Action": "s3:GetObject",
      "Resource": [
		"${aws_s3_bucket.documentation.arn}",
		"${aws_s3_bucket.documentation.arn}/*"
	  ]
    }
  ]
}
POLICY
  depends_on = [aws_s3_bucket_public_access_block.documentation]
}

resource "aws_s3_object" "swagger_index" {
  key          = "index.html"
  source       = "../../doc/index.html"
  bucket       = aws_s3_bucket.documentation.id
  content_type = "text/html"

  etag = filemd5("../../doc/index.html")
}

resource "aws_s3_object" "api_definition" {
  key    = "api.yml"
  source = "../../doc/api.yml"
  bucket = aws_s3_bucket.documentation.id

  depends_on = [null_resource.openapi_export]
  lifecycle {
    replace_triggered_by = [
      null_resource.always_run
    ]
  }
}