resource "aws_iam_role" "role" {
  name = "LambdaRole"

  assume_role_policy = <<POLICY
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": "sts:AssumeRole",
      "Principal": {
        "Service": "lambda.amazonaws.com"
      },
      "Effect": "Allow",
      "Sid": ""
    }
  ]
}
POLICY
}

resource "aws_lambda_function" "hello_world" {
  filename         = "${var.services_path}/hello_world.zip"
  function_name    = "hello_world"
  role             = aws_iam_role.role.arn
  handler          = "hello_world.lambda_handler"
  runtime          = "python3.9"
  source_code_hash = filebase64sha256("${var.services_path}/hello_world.zip")
}

resource "aws_lambda_permission" "apigw_lambda" {
  action        = "lambda:InvokeFunction"
  function_name = aws_lambda_function.hello_world.function_name
  principal     = "apigateway.amazonaws.com"
  source_arn    = "arn:aws:execute-api:${var.region}:${local.current_account_id}:${aws_api_gateway_rest_api.this.id}/*/${aws_api_gateway_method.hello_world_get.http_method}${aws_api_gateway_resource.hello_world.path}"
  statement_id  = "AllowExecutionFromAPIGateway"
}